#!/usr/bin/env python

import unittest

import imdb


def personInMovie(p, m):
    if p in m:
        return 1
    return 0

def getKey(m, k):
    return m[k]


class MovieTC(unittest.TestCase):
    def testCreateEmpty(self):
        m = imdb.Movie.Movie()
        if m:
            self.fail('the Movie object should be false!')

    def testCreateNotEmpty(self):
        m = imdb.Movie.Movie(title='movie title')
        if not m:
            self.fail('the Movie object should be true!')

    def testMovieTitle(self):
        m_title = 'movie title'
        m = imdb.Movie.Movie(title=m_title)
        self.failUnlessEqual(m_title, m['title'])
    
    def testMovieTitleGet(self):
        m_title = 'movie title'
        m = imdb.Movie.Movie(title=m_title)
        self.failUnlessEqual(m_title, m.get('title'))
    
    def testMovieLongTitle(self):
        m = imdb.Movie.Movie(title='movie title')
        self.failUnlessEqual('movie title (????)', m.get('long imdb title'))

    def testMovieNoLongTitle(self):
        m = imdb.Movie.Movie()
        self.failUnlessEqual(None, m.get('long imdb title'))

    def testMovieCompare1(self):
        m1 = imdb.Movie.Movie(title='"tv mini-series" (1996/IV) (mini)')
        d = {
            'title':        'tv mini-series',
            'kind':         'tv mini series',
            'year':         '1996',
            'imdbIndex':    'IV'}
        m2 = imdb.Movie.Movie(movieData=d)
        self.failUnlessEqual(m1, m2)

    def testMovieCompare2(self):
        m1 = imdb.Movie.Movie(title='"tv mini-series" (1996/IV) (mini)')
        d = {
            'title':        'tv mini-series',
            'kind':         'tv mini series',
            'year':         '1996',
            'imdbIndex':    'IV',
            'rating':       '7.8/10'}
        m2 = imdb.Movie.Movie(movieData=d)
        self.failIfEqual(m1, m2)
       

    def testMovieCompareTitle1(self):
        m1 = imdb.Movie.Movie(title='"tv mini-series" (1996/IV) (mini)')
        d = {
            'title':        'tv mini-series',
            'kind':         'tv mini series',
            'year':         '1996',
            'imdbIndex':    'IV',
            'rating':       '7.8/10'}
        m2 = imdb.Movie.Movie(movieData=d)
        self.failUnless(m1.isSameTitle(m2))
        
    def testMovieCompareTitle2(self):
        m1 = imdb.Movie.Movie(title='"tv mini-series" (1996/IV) (mini)')
        d = {
            'title':        'tv mini-series',
            'kind':         'tv mini series',
            'year':         '1996',
            'rating':       '7.8/10'}
        m2 = imdb.Movie.Movie(movieData=d)
        self.failIf(m1.isSameTitle(m2))

    def testMovieCompareTitle3(self):
        m1 = imdb.Movie.Movie(title='movie title', movieID='1',
                                accessSystem='web')
        d = {
            'title':        'another title',
            'kind':         'tv mini series',
            'year':         '1996',
            'rating':       '7.8/10'}
        m2 = imdb.Movie.Movie(movieData=d)
        m2.accessSystem = 'web'
        m2.movieID = '1'
        self.failUnless(m1.isSameTitle(m2))

    def testPersonIn1(self):
        p = imdb.Person.Person(name='Gino Pino (II)')
        d = {'cast': [p]}
        m = imdb.Movie.Movie(title='movie title', movieData=d)
        self.failUnless(personInMovie(p, m))

    def testPersonIn2(self):
        p1 = imdb.Person.Person(name='Gino Pino (II)')
        p2 = imdb.Person.Person(name='Gino Pino')
        d = {'cast': [p1]}
        m = imdb.Movie.Movie(title='movie title', movieData=d)
        self.failIf(personInMovie(p2, m))
    
    def testPersonIn3(self):
        p1 = imdb.Person.Person(name='Gino Pino (II)')
        p2 = imdb.Person.Person(name='Gino Pino (I)')
        d = {'cast': [p1]}
        m = imdb.Movie.Movie(title='movie title', movieData=d)
        self.failIf(personInMovie(p2, m))

    def testKeyAliases1(self):
        p = imdb.Person.Person(name='Gina Pina')
        d = {'cast': [p]}
        m = imdb.Movie.Movie(title='movie title', movieData=d)
        self.failUnlessRaises(KeyError, getKey, m, 'crusty')

    def testKeyAliases2(self):
        p = imdb.Person.Person(name='Gina Pina')
        d = {'cast': [p]}
        m = imdb.Movie.Movie(title='movie title', movieData=d)
        self.failUnlessEqual([p], getKey(m, 'actresses'))


if __name__ == '__main__':
    unittest.main()


