#!/usr/bin/env python

import unittest

import imdb

from imdb import utils


def an_name(name):
    return utils.analyze_name(name)

def an_title(title):
    return utils.analyze_title(title)

def b_name(d):
    return utils.build_name(d)

def b_title(d):
    return utils.build_title(d)


class NameTC(unittest.TestCase):
    def testInvalidName(self):
        self.failUnlessRaises(imdb._exceptions.IMDbParserError,
                                an_name, '  ')
    
    def testValidName1(self):
        n = 'person name'
        d = {'name': 'person name'}
        self.failUnlessEqual(d, an_name(n))

    def testValidName2(self):
        n = 'person name (VI)'
        d = {'name': 'person name', 'imdbIndex': 'VI'}
        self.failUnlessEqual(d, an_name(n))

    def testCreate1(self):
        d = {'name': 'person name', 'imdbIndex': 'VI'}
        n = 'person name (VI)'
        self.failUnlessEqual(n, b_name(d))

    def testCreate2(self):
        d = {'name': 'person name', 'imdbIndex': 'VI', 'key1': 'val1'}
        n = 'person name (VI)'
        self.failUnlessEqual(n, b_name(d))


class TitleTC(unittest.TestCase):
    def testInvalidTitle(self):
        self.failUnlessRaises(imdb._exceptions.IMDbParserError,
                                an_title, '  ')

    def testValidTitle1(self):
        t = 'movie title'
        d = {'title': 'movie title', 'kind': 'movie'}
        self.failUnlessEqual(d, an_title(t))

    def testValidTitle2(self):
        t = 'movie title (????)'
        d = {'title': 'movie title', 'kind': 'movie'}
        self.failUnlessEqual(d, an_title(t))

    def testValidTitle3(self):
        t = '"tv mini" (1993/I) (mini)'
        d = {'title': 'tv mini', 'kind': 'tv mini series', 'year': '1993',
            'imdbIndex': 'I'}
        self.failUnlessEqual(d, an_title(t))

    def testValidTitle4(self):
        t = '"tv series" (1993)'
        d = {'title': 'tv series', 'kind': 'tv series', 'year': '1993'}
        self.failUnlessEqual(d, an_title(t))

    def testValidTitle5(self):
        t = 'video movie title (2001) (V)'
        d = {'title': 'video movie title', 'kind': 'video movie',
            'year': '2001'}
        self.failUnlessEqual(d, an_title(t))

    def testValidTitle6(self):
        t = 'tv movie title (1997) (TV)'
        d = {'title': 'tv movie title', 'kind': 'tv movie', 'year': '1997'}
        self.failUnlessEqual(d, an_title(t))

    def testValidTitle7(self):
        t = 'video game title (1993) (VG)'
        d = {'title': 'video game title', 'kind': 'video game', 'year': '1993'}
        self.failUnlessEqual(d, an_title(t))

    def testCreate1(self):
        t = 'movie title (????)'
        d = {'title': 'movie title', 'kind': 'movie'}
        self.failUnlessEqual(t, b_title(d))

    def testCreate2(self):
        t = 'movie title (????)'
        d = {'title': 'movie title', 'kind': 'movie', 'key1': 'value1'}
        self.failUnlessEqual(t, b_title(d))

    def testCreate3(self):
        t = '"tv mini" (1993/I) (mini)'
        d = {'title': 'tv mini', 'kind': 'tv mini series', 'year': '1993',
            'imdbIndex': 'I'}
        self.failUnlessEqual(t, b_title(d))

    def testCreate4(self):
        t = '"tv series" (1993)'
        d = {'title': 'tv series', 'kind': 'tv series', 'year': '1993'}
        self.failUnlessEqual(t, b_title(d))

    def testCreate5(self):
        t = 'video movie title (2001) (V)'
        d = {'title': 'video movie title', 'kind': 'video movie',
            'year': '2001'}
        self.failUnlessEqual(t, b_title(d))

    def testCreate6(self):
        t = 'tv movie title (1997) (TV)'
        d = {'title': 'tv movie title', 'kind': 'tv movie', 'year': '1997'}
        self.failUnlessEqual(t, b_title(d))

    def testCreate7(self):
        t = 'video game title (1993) (VG)'
        d = {'title': 'video game title', 'kind': 'video game', 'year': '1993'}
        self.failUnlessEqual(t, b_title(d))


if __name__ == '__main__':
    unittest.main()


